﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub HP 437B Cal Factor Utility IEEE
DATE:                  2009-11-12
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       1
NUMBER OF LINES:       201
CONFIGURATION:         HP 437B
=============================================================================
#
#  Procedure Author(s):
#        DAC, MS, DFM
#
#  Model(s) Covered:
#        437B
#
#  Source:
#        Agilent Technologies, Operating Manual, 437B Power Meter, Part No.
#         00437-90047, January 1997
#
#  Compatibility:
#        MET/CAL 7.20 SP3 (7.20Z) or later
#
#  Subprocedure(s):
#        Sub HP 437B Review Cal Factors IEEE
#        Sub HP 437B Enter Cal Factors IEEE
#        Sub HP 437B Delete Cal Factors IEEE
#
#  The Procedure was tested using:
#
#        Model No.    : 437B
#        Serial No.   : 3125U11556
#        Options      : None
#        Firmware Rev.: 2.0
#
#  Additional Information
#
#        The cal factor table has the following format:
#
#          Frequency         Cal Factors
#        --------------   ----------------
#              --          ref cal factor
#         frequency 1       cal factor 1
#         frequency 2       cal factor 2
#         frequency 3       cal factor 3
#             .                  .
#             .                  .
#         frequency n       cal factor n
#
#
#        The following cal factor tables exist:
#
#         Sensor Data Table        Power Sensor
#        -------------------  ----------------------
#              Table 0        DEFAULT (100%, all frequencies)
#              Table 1               HP 8481A
#              Table 2        HP 8482A, 8482B, 8482H
#              Table 3               HP 8483A
#              Table 4               HP 8481D (8484A)
#              Table 5               HP 8485A
#              Table 6               HP R8486A
#              Table 7               HP Q8486A
#              Table 8               HP R8486D
#              Table 9               HP 8487A
#
#        The following rules apply:
#
#        o RF Frequency Range:              100 kHz - 99.98 GHz RF Frequency
#        o Frequency Resolution:            10 kHz/10 MHz
#        o Cal Factor Range:                1-150%
#        o Cal Factor Resolution:           0.1%
#        o Maximum number of entries/table:
#               - Tables 0 thru 7: 40 (frequency), 41 (cal factor)
#               - Tables 8 thru 9: 80 (frequency), 81 (cal factor)
#        o The frequencies must be entered in ascending order.
#        o All frequencies are truncated to a multiple of 10 kHz/10 MHz,
#          depending on cal factor frequency units.
#
#  NOTE: This procedure has no explict error checking of 437B remote commands.
#  MET/CAL 5.0 or later, configuring an 437B establishes the alias 437. If a
#  command in an IEEE FSC in this procedure causes an error, it is caught by
#  the SRQ handler in the MET/CAL 437B driver.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  HEAD         PRELIMINARY INFORMATION
  1.002  DISP         This utility enables the operator to review, enter, or
  1.002  DISP         delete sensor calibration table data, used to correct
  1.002  DISP         measurement results for the applicable power sensor.
  1.002  DISP
  1.002  DISP         Calibration tables in the configured power meter, as
  1.002  DISP         defined in the 437B Operating Manual, i.e., HP/Agilent
  1.002  DISP         8480-series sensors, are supported.

  1.003  DO
  1.004  HEAD         CAL FACTOR INFORMATION
  1.005  MATH         Id = LBNEW("HP 437B Power Meter")
  1.006  MATH         LBTEXT(Id, "Select desired cal factor table.")
  1.007  MATH         LBCONF(Id, "+SelReq,+ok,+term,-border")

  1.008  MATH         LBADD(Id, " DEFAULT")
  1.009  MATH         LBADD(Id, " HP 8481A")
  1.010  MATH         LBADD(Id, " HP 8482A, 8482B, 8482H")
  1.011  MATH         LBADD(Id, " HP 8483A")
  1.012  MATH         LBADD(Id, " HP 8481D (8484A)")
  1.013  MATH         LBADD(Id, " HP 8485A")
  1.014  MATH         LBADD(Id, " HP R8487A")
  1.015  MATH         LBADD(Id, " HP Q8486A")
  1.016  MATH         LBADD(Id, " HP R8486D")
  1.017  MATH         LBADD(Id, " HP 8487A")

  1.018  MATH         Cancel = LBSHOW(Id)
  1.019  MATH         @TableNum = (LBGETSELX(Id, 1)) - 1

  1.020  IF           Cancel < 2
# Strip white spaces (added above) prior to storing variable data.
  1.021  MATH         @Table = STRIPL(LBGETSEL(Id, 1))

  1.022  MATH         IdFunc = LBNEW(@Table & " Cal Factor Table")
  1.023  MATH         LBTEXT(IdFunc, "Select desired CF table action.")
  1.024  MATH         LBBUTTON(IdFunc, "Review")
  1.025  MATH         LBBUTTON(IdFunc, "Enter")
  1.026  MATH         LBBUTTON(IdFunc, "Delete")
  1.027  MATH         LBBUTTON(IdFunc, "Cancel")
  1.028  MATH         Selection = LBSHOW(IdFunc)

  1.029  WHILE        Selection < 4

# ------- Cal Factor Review

  1.030  IF           Selection == 1
  1.031  CALL         Sub HP 437B Review Cal Factors IEEE

  1.032  IF           NOT(@CalFactorsOk)
  1.033  OPBR         -z Do you wish to ENTER new values to the currently
  1.033  OPBR         selected sensor table, [V @Table]?

  1.034  IF           MEM1
  1.035  MATH         Selection = 2
  1.036  ELSE
  1.037  MATH         Selection = 4
  1.038  ENDIF

  1.039  ELSE
  1.040  MATH         Selection = 4
  1.041  ENDIF

# ------- Cal Factor Entry

  1.042  ELSEIF       Selection == 2

  1.043  DO
  1.044  CALL         Sub HP 437B Enter Cal Factors IEEE
  1.045  UNTIL        @CalFactorsOk

  1.046  IF           NOT(@Abort)
  1.047  OPBR         -z Do you wish to REVIEW the Cal Factor data just
  1.047  OPBR         entered for the [V @Table] sensor table?

  1.048  IF           MEM1
  1.049  MATH         Selection = 1
  1.050  ELSE
  1.051  MATH         Selection = 4
  1.052  ENDIF

  1.053  ELSE
  1.054  MATH         Selection = 4
  1.055  ENDIF

# ------- Cal Factor Deletion

  1.056  ELSEIF       Selection == 3
  1.057  OPBR         -z Do you wish to DELETE the current contents of sensor
  1.057  OPBR         calibration table [V @Table]?

  1.058  IF           MEM1
  1.059  CALL         Sub HP 437B Delete Cal Factors IEEE
  1.060  ENDIF

  1.061  MATH         Selection = 4
  1.062  ENDIF

  1.063  ENDW

  1.064  ENDIF        ; Cancel table selection

  1.065  LABEL        REPEAT
  1.066  OPBR         -z Do you wish to REVIEW/ENTER/DELETE Cal Factor data
  1.066  OPBR         for another sensor calibration table?

  1.067  UNTIL        NOT(MEM1)

  1.068  LABEL        END
  1.069  IEEE         [@437]*CLS;PR
  1.070  END
