﻿© Fluke. All Rights Reserved.                               MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub MS272xB Power Splitter Characterization /437,SWPG
DATE:                  2009-11-19
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       21
NUMBER OF LINES:       708
CONFIGURATION:         HP 437B
CONFIGURATION:         Sweep Generator
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        MS2721B, MS2723B
#
#  Compatibility:
#        MET/CAL 7.20x or later
#
#  Subprocedures:
#        Sub Anritsu MS272xB Take Sweep (MKPK)
#        Sub MS272xB Set Ref Level VISA /SWPG
#        Sub Level Signal /437,SWPG
#
#  Required Files:
#        11667A_<AssetPowSpltr>_char.ini
#        swpg_437b_ms272x_spltr_fwd.jpg
#        swpg_437b_ms272x_spltr_rev.jpg
#
#  Additional Equipment Required:
#        Power Splitter, 50 Ohms, DC to 18 GHz, Type N, HP/Agilent 11667A or
#          equivalent
#        Adapter, Type N (m) to Type N (m), 50 Ohms
#        Cable, coaxial, Type N (m)-(m), 50 Ohms, 36"
#
#  Overview:
#  In order to alleviate the port-to-port tracking error of the power splitter
#  from the uncertainty components, the flatness of Port 2 is first measured
#  and the resultant values saved. The splitter is then reversed and the
#  measurements repeated. The actual flatness is computed using the difference
#  of the two measurements, relative to the same UUT 50 MHz reference reading
#  and absolute power. For example, if the output tracking error (Port 3) is
#  reported as -0.44 dB, 0.44 dB LESS POWER, as measured with the power meter,
#  for the same output on Port 2 (the UUT side) in this procedure. This value
#  is then used as a correction during the UUT amplitude vs. frequency
#  verification.
#
#  Based on historical evidence of the 11667A stability, the characterization
#  is considered to be valid for 30 days.
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

  1.001  IF           0
  1.002  IEEE         [@SWPG]
  1.003  M437                                      HP8481A
  1.004  ENDIF

  1.005  MATH         AssetPowSpltr = ASSET(@PowSpltr)
  1.006  MATH         FileName = "11667A_" & AssetPowSpltr & "_char"
  1.007  MATH         @FileName = FileName & ".ini"
  1.008  CALL         Sub RIF/WIF Directory
  1.009  MATH         @IniFile = @RifWifDir & "\\" & @FileName

  1.010  IF           EXISTS(@IniFile)
  1.011  MATH         @Section = "timestamp"
  1.012  MATH         @Parameter = "time"
  1.013  MATH         TimeStamp = RIF(@IniFile, @Section, @Parameter)

  1.014  IF           EMPTY(TimeStamp) || NOT(IS_NUM(TimeStamp))
  1.015  CALL         Sub RIF Error

  1.016  IF           @Error
  1.017  END
  1.018  ENDIF

  1.019  ELSE
# 2592000 is the number of seconds in 30 days, the period it is valid.
  1.020  MATH         Valid = 2592000 - (UTIME() - TimeStamp)

# Check to see if otherwise valid file was externally modified since creation.
  1.021  IF           TimeStamp - MTIME(@IniFile)
  1.022  MATH         Valid = 0
  1.023  ENDIF

  1.024  ENDIF        ; EMPTY(TimeStamp) || NOT(IS_NUM(TimeStamp))

  1.025  ELSE
  1.026  MATH         Valid = 0
  1.027  ENDIF        ; EXISTS(@IniFile)

  1.028  IF           NOT(EXISTS(@IniFile)) || NOT(Valid)
  1.029  HEAD         POWER SPLITTER CHARACTERIZATION
  1.030  HEAD         -2 [7][D250][7][D250][7][D250][7][D250][7]
  1.031  HEAD         -2 Create 11667A Initialization File
  1.032  MATH         @Section = "timestamp"
  1.033  MATH         @Parameter = "time"
  1.034  MATH         TimeStamp = UTIME()
  1.035  MATH         Insert = WIF(@IniFile, @Section, @Parameter, TimeStamp)

  1.036  IF           NOT(Insert)
  1.037  CALL         Sub WIF Error

  1.038  IF           @Error
  1.039  END
  1.040  ENDIF

  1.041  ENDIF

  1.042  HEAD         -2 Reference Set (Port 2): 50 MHz
  1.043  TARGET       -p
  1.044  CALL         Sub Initialize /SWPG
  1.045  CALL         Sub Reset /SWPG

  1.046  PIC          swpg_437b_ms272x_spltr_fwd.jpg
  1.047  VISA         SYST:PRES[10]
  1.048  VISA         INIT:CONT OFF
  1.049  VISA         FREQ:CENT 50E+6;SPAN 10E+3;:BWID:RES 1E+3;VID 10
  1.050  VISA         DISP:WIND:TRAC:Y:RLEV 10;:POW:ATT 30;AUTO OFF
  1.051  MATH         @SWPG_Freq = "50MHz"; @SWPG_Ampl = "+4dBm"
  1.052  MATH         @SWPG_ROSC = "Ext"
  1.053  CALL         Sub Apply /SWPG
  1.054  MATH         @TestName = "Splitter Characterization"; @Error = 0
  1.055  MATH         @RefLvl = -2; @TestLvl = +4
  1.056  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
  1.057  VISA         CALC:MARK:Y?[I]

# Adjust SWPG level for a value of -2 dBm as read on UUT.
  1.058  WHILE        ((MEM < -2.05) || (MEM > -1.95)) && NOT(@Error)
  1.059  CALL         Sub MS272xB Set Ref Level VISA /SWPG
  1.060  ENDW

  1.061  IF           @Error
# EVAL to force "FAIL" in test results as well as to notify operator.
  1.062  EVAL   -e 0 : An error occurred during the [V @TestName].
# Reset 'error' variable to false following error detection is sub.
  2.001  MATH         @Error = 0
  2.002  END
  2.003  ENDIF

  2.004  M437   HIGH                 F128          HP8481A        T1
# Measure 50 MHz power reference level, for leveling and computation.
  2.005  437          -2.00D                       50MH              RF N
# Save 50 MHz Port 2 value and use it for a power reference for remaining
# Port 2 measurements.
  2.006  MATH         @50MHz_2 = MEM; @RefLvl = MEM
# Set limits for leveling sub based on measured power reference value.
  2.007  MATH         @HiLimit = @RefLvl + 0.05; @LoLimit = @RefLvl - 0.05

  2.008  HEAD         -2 Power Splitter Tracking (Port 2): 5 GHz
  2.009  MATH         @SWPG_Freq = "5GHz"
  2.010  CALL         Sub Apply /SWPG
  2.011  VISA         FREQ:CENT 5E+9
  2.012  MATH         @CenterFreq = 5E+9; @TestLvl = +4
  2.013  437          -2.00D                       5GH               RF N

# Adjust power at test frequency to be equal to that at 50 MHz reference.
  2.014  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
  2.015  CALL         Sub Level Signal /437,SWPG
  2.016  ENDW

  2.017  IF           @Error
  2.018  EVAL   -e 0 : An error occurred during the [V @TestName].
  3.001  MATH         @Error = 0
  3.002  END
  3.003  ENDIF

# Measure (Port 2) level on UUT, storing for subsequent tracking computation.
  3.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
  3.005  VISA         CALC:MARK:Y?[I]
  3.006  MATH         @5GHz_2 = MEM

  3.007  HEAD         -2 Power Splitter Tracking (Port 2): 6 GHz
  3.008  MATH         @SWPG_Freq = "6GHz"
  3.009  CALL         Sub Apply /SWPG
  3.010  VISA         FREQ:CENT 6E+9
  3.011  MATH         @CenterFreq = 6E+9
  3.012  437          -2.00D                       6GH               RF N

  3.013  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
  3.014  CALL         Sub Level Signal /437,SWPG
  3.015  ENDW

  3.016  IF           @Error
  3.017  EVAL   -e 0 : An error occurred during the [V @TestName].
  4.001  MATH         @Error = 0
  4.002  END
  4.003  ENDIF

  4.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
  4.005  VISA         CALC:MARK:Y?[I]
  4.006  MATH         @6GHz_2 = MEM

  4.007  HEAD         -2 Power Splitter Tracking (Port 2): 7 GHz
  4.008  MATH         @SWPG_Freq = "7GHz"
  4.009  CALL         Sub Apply /SWPG
  4.010  VISA         FREQ:CENT 7E+9
  4.011  MATH         @CenterFreq = 7E+9
  4.012  437          -2.00D                       7GH               RF N

  4.013  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
  4.014  CALL         Sub Level Signal /437,SWPG
  4.015  ENDW

  4.016  IF           @Error
  4.017  EVAL   -e 0 : An error occurred during the [V @TestName].
  5.001  MATH         @Error = 0
  5.002  END
  5.003  ENDIF

  5.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
  5.005  VISA         CALC:MARK:Y?[I]
  5.006  MATH         @7GHz_2 = MEM

  5.007  IF           NOT(ZCMPI(@ModelNum, "MS2721B"))
  5.008  HEAD         -2 Power Splitter Tracking (Port 2): 8 GHz
  5.009  MATH         @SWPG_Freq = "8GHz"
  5.010  CALL         Sub Apply /SWPG
  5.011  VISA         FREQ:CENT 8E+9
  5.012  MATH         @CenterFreq = 8E+9
  5.013  437          -2.00D                       8GH               RF N

  5.014  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
  5.015  CALL         Sub Level Signal /437,SWPG
  5.016  ENDW

  5.017  IF           @Error
  5.018  EVAL   -e 0 : An error occurred during the [V @TestName].
  6.001  MATH         @Error = 0
  6.002  END
  6.003  ENDIF

  6.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
  6.005  VISA         CALC:MARK:Y?[I]
  6.006  MATH         @8GHz_2 = MEM

  6.007  HEAD         -2 Power Splitter Tracking (Port 2): 9 GHz
  6.008  MATH         @SWPG_Freq = "9GHz"
  6.009  CALL         Sub Apply /SWPG
  6.010  VISA         FREQ:CENT 9E+9
  6.011  MATH         @CenterFreq = 9E+9
  6.012  437          -2.00D                       9GH               RF N

  6.013  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
  6.014  CALL         Sub Level Signal /437,SWPG
  6.015  ENDW

  6.016  IF           @Error
  6.017  EVAL   -e 0 : An error occurred during the [V @TestName].
  7.001  MATH         @Error = 0
  7.002  END
  7.003  ENDIF

  7.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
  7.005  VISA         CALC:MARK:Y?[I]
  7.006  MATH         @9GHz_2 = MEM

  7.007  HEAD         -2 Power Splitter Tracking (Port 2): 10 GHz
  7.008  MATH         @SWPG_Freq = "10GHz"
  7.009  CALL         Sub Apply /SWPG
  7.010  VISA         FREQ:CENT 10E+9
  7.011  MATH         @CenterFreq = 10E+9
  7.012  437          -2.00D                       10GH              RF N

  7.013  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
  7.014  CALL         Sub Level Signal /437,SWPG
  7.015  ENDW

  7.016  IF           @Error
  7.017  EVAL   -e 0 : An error occurred during the [V @TestName].
  8.001  MATH         @Error = 0
  8.002  END
  8.003  ENDIF

  8.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
  8.005  VISA         CALC:MARK:Y?[I]
  8.006  MATH         @10GHz_2 = MEM

  8.007  HEAD         -2 Power Splitter Tracking (Port 2): 11 GHz
  8.008  MATH         @SWPG_Freq = "11GHz"
  8.009  CALL         Sub Apply /SWPG
  8.010  VISA         FREQ:CENT 11E+9
  8.011  MATH         @CenterFreq = 11E+9
  8.012  437          -2.00D                       11GH              RF N

  8.013  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
  8.014  CALL         Sub Level Signal /437,SWPG
  8.015  ENDW

  8.016  IF           @Error
  8.017  EVAL   -e 0 : An error occurred during the [V @TestName].
  9.001  MATH         @Error = 0
  9.002  END
  9.003  ENDIF

  9.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
  9.005  VISA         CALC:MARK:Y?[I]
  9.006  MATH         @11GHz_2 = MEM

  9.007  HEAD         -2 Power Splitter Tracking (Port 2): 12 GHz
  9.008  MATH         @SWPG_Freq = "12GHz"
  9.009  CALL         Sub Apply /SWPG
  9.010  VISA         FREQ:CENT 12E+9
  9.011  MATH         @CenterFreq = 12E+9
  9.012  437          -2.00D                       12GH              RF N

  9.013  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
  9.014  CALL         Sub Level Signal /437,SWPG
  9.015  ENDW

  9.016  IF           @Error
  9.017  EVAL   -e 0 : An error occurred during the [V @TestName].
 10.001  MATH         @Error = 0
 10.002  END
 10.003  ENDIF

 10.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 10.005  VISA         CALC:MARK:Y?[I]
 10.006  MATH         @12GHz_2 = MEM

 10.007  HEAD         -2 Power Splitter Tracking (Port 2): 13 GHz
 10.008  MATH         @SWPG_Freq = "13GHz"
 10.009  CALL         Sub Apply /SWPG
 10.010  VISA         FREQ:CENT 13E+9
 10.011  MATH         @CenterFreq = 13E+9
 10.012  437          -2.00D                       13GH              RF N

 10.013  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 10.014  CALL         Sub Level Signal /437,SWPG
 10.015  ENDW

 10.016  IF           @Error
 10.017  EVAL   -e 0 : An error occurred during the [V @TestName].
 11.001  MATH         @Error = 0
 11.002  END
 11.003  ENDIF

 11.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 11.005  VISA         CALC:MARK:Y?[I]
 11.006  MATH         @13GHz_2 = MEM

 11.007  ENDIF

 11.008  HEAD         -2 [7][D250][7][D250][7][D250][7][D250][7]
 11.009  PIC          swpg_437b_ms272x_spltr_rev.jpg

 11.010  HEAD         -2 Reference Set (Port 3): 50 MHz
 11.011  MATH         @SWPG_Freq = "50MHz"
 11.012  CALL         Sub Apply /SWPG
 11.013  VISA         FREQ:CENT 50E+6
 11.014  MATH         @RefLvl = -2; @TestLvl = +4
 11.015  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 11.016  VISA         CALC:MARK:Y?[I]

# Again adjust SWPG level for a value of -2 dBm as read on UUT.
 11.017  WHILE        ((MEM < -2.05) || (MEM > -1.95)) && NOT(@Error)
 11.018  CALL         Sub MS272xB Set Ref Level VISA /SWPG
 11.019  ENDW

 11.020  IF           @Error
 11.021  EVAL   -e 0 : An error occurred during the [V @TestName].
 12.001  MATH         @Error = 0
 12.002  END
 12.003  ENDIF

 12.004  437          -2.00D                       50MH              RF N
# Compute splitter port 3 tracking error relative to port 2, in absolute
# power. Store absolute power level for use in leveling sub.
 12.005  MATH         @50MHz_3 = MEM - @50MHz_2; @RefLvl = MEM
# Reset levling limits for use in sub.
 12.006  MATH         @HiLimit = @RefLvl + 0.05; @LoLimit = @RefLvl - 0.05

 12.007  HEAD         -2 Insert 50 MHz Splitter Error (Port 3 vs. Port 2)
 12.008  MATH         @Parameter = "output_tracking_error"
 12.009  MATH         @Section = "50_MHz"
 12.010  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @50MHz_3)

 12.011  IF           NOT(Insert)
 12.012  CALL         Sub WIF Error

 12.013  IF           @Error
 12.014  END
 12.015  ENDIF

 12.016  ENDIF

 12.017  HEAD         -2 Power Splitter Tracking (Port 3): 5 GHz
 12.018  MATH         @SWPG_Freq = "5GHz"
 12.019  CALL         Sub Apply /SWPG
 12.020  VISA         FREQ:CENT 5E+9
 12.021  MATH         @CenterFreq = 5E+9; @TestLvl = +4
 12.022  437          -2.00D                       5GH               RF N

 12.023  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 12.024  CALL         Sub Level Signal /437,SWPG
 12.025  ENDW

 12.026  IF           @Error
 12.027  EVAL   -e 0 : An error occurred during the [V @TestName].
 13.001  MATH         @Error = 0
 13.002  END
 13.003  ENDIF

# Measure UUT with same amount of power applied as at 50 MHz.
 13.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 13.005  VISA         CALC:MARK:Y?[I]
# Compute splitter port 3 tracking error relative to port 2, using the UUT
# marker value.
 13.006  MATH         @5GHz_3 = (MEM - @5GHz_2)
 13.007  HEAD         -2 Insert 5 GHz Splitter Error (Port 3 vs. Port 2)
 13.008  MATH         @Section = "5_GHz"
 13.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @5GHz_3)

 13.010  IF           NOT(Insert)
 13.011  CALL         Sub WIF Error

 13.012  IF           @Error
 13.013  END
 13.014  ENDIF

 13.015  ENDIF

 13.016  HEAD         -2 Power Splitter Tracking (Port 3): 6 GHz
 13.017  MATH         @SWPG_Freq = "6GHz"
 13.018  CALL         Sub Apply /SWPG
 13.019  VISA         FREQ:CENT 6E+9
 13.020  MATH         @CenterFreq = 6E+9
 13.021  437          -2.00D                       6GH               RF N

 13.022  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 13.023  CALL         Sub Level Signal /437,SWPG
 13.024  ENDW

 13.025  IF           @Error
 13.026  EVAL   -e 0 : An error occurred during the [V @TestName].
 14.001  MATH         @Error = 0
 14.002  END
 14.003  ENDIF

 14.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 14.005  VISA         CALC:MARK:Y?[I]
 14.006  MATH         @6GHz_3 = (MEM - @6GHz_2)
 14.007  HEAD         -2 Insert 6 GHz Splitter Error (Port 3 vs. Port 2)
 14.008  MATH         @Section = "6_GHz"
 14.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @6GHz_3)

 14.010  IF           NOT(Insert)
 14.011  CALL         Sub WIF Error

 14.012  IF           @Error
 14.013  END

 14.014  ENDIF

 14.015  ENDIF

 14.016  HEAD         -2 Power Splitter Tracking (Port 3): 7 GHz
 14.017  MATH         @SWPG_Freq = "7GHz"
 14.018  CALL         Sub Apply /SWPG
 14.019  VISA         FREQ:CENT 7E+9
 14.020  MATH         @CenterFreq = 7E+9
 14.021  437          -2.00D                       7GH               RF N

 14.022  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 14.023  CALL         Sub Level Signal /437,SWPG
 14.024  ENDW

 14.025  IF           @Error
 14.026  EVAL   -e 0 : An error occurred during the [V @TestName].
 15.001  MATH         @Error = 0
 15.002  END
 15.003  ENDIF

 15.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 15.005  VISA         CALC:MARK:Y?[I]
 15.006  MATH         @7GHz_3 = (MEM - @7GHz_2)
 15.007  HEAD         -2 Insert 7 GHz Splitter Error (Port 3 vs. Port 2)
 15.008  MATH         @Section = "7_GHz"
 15.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @7GHz_3)

 15.010  IF           NOT(Insert)
 15.011  CALL         Sub WIF Error

 15.012  IF           @Error
 15.013  END
 15.014  ENDIF

 15.015  ENDIF

 15.016  IF           NOT(ZCMPI(@ModelNum, "MS2721B"))
 15.017  HEAD         -2 Power Splitter Tracking (Port 3): 8 GHz
 15.018  MATH         @SWPG_Freq = "8GHz"
 15.019  CALL         Sub Apply /SWPG
 15.020  VISA         FREQ:CENT 8E+9
 15.021  MATH         @CenterFreq = 8E+9
 15.022  437          -2.00D                       8GH               RF N

 15.023  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 15.024  CALL         Sub Level Signal /437,SWPG
 15.025  ENDW

 15.026  IF           @Error
 15.027  EVAL   -e 0 : An error occurred during the [V @TestName].
 16.001  MATH         @Error = 0
 16.002  END
 16.003  ENDIF

 16.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 16.005  VISA         CALC:MARK:Y?[I]
 16.006  MATH         @8GHz_3 = (MEM - @8GHz_2)
 16.007  HEAD         -2 Insert 8 GHz Splitter Error (Port 3 vs. Port 2)
 16.008  MATH         @Section = "8_GHz"
 16.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @8GHz_3)

 16.010  IF           NOT(Insert)
 16.011  CALL         Sub WIF Error

 16.012  IF           @Error
 16.013  END
 16.014  ENDIF

 16.015  ENDIF

 16.016  HEAD         -2 Power Splitter Tracking (Port 3): 9 GHz
 16.017  MATH         @SWPG_Freq = "9GHz"
 16.018  CALL         Sub Apply /SWPG
 16.019  VISA         FREQ:CENT 9E+9
 16.020  MATH         @CenterFreq = 9E+9
 16.021  437          -2.00D                       9GH               RF N

 16.022  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 16.023  CALL         Sub Level Signal /437,SWPG
 16.024  ENDW

 16.025  IF           @Error
 16.026  EVAL   -e 0 : An error occurred during the [V @TestName].
 17.001  MATH         @Error = 0
 17.002  END
 17.003  ENDIF

 17.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 17.005  VISA         CALC:MARK:Y?[I]
 17.006  MATH         @9GHz_3 = (MEM - @9GHz_2)
 17.007  HEAD         -2 Insert 9 GHz Splitter Error (Port 3 vs. Port 2)
 17.008  MATH         @Section = "9_GHz"
 17.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @9GHz_3)

 17.010  IF           NOT(Insert)
 17.011  CALL         Sub WIF Error

 17.012  IF           @Error
 17.013  END
 17.014  ENDIF

 17.015  ENDIF

 17.016  HEAD         -2 Power Splitter Tracking (Port 3): 10 GHz
 17.017  MATH         @SWPG_Freq = "10GHz"
 17.018  CALL         Sub Apply /SWPG
 17.019  VISA         FREQ:CENT 10E+9
 17.020  MATH         @CenterFreq = 10E+9
 17.021  437          -2.00D                       10GH              RF N

 17.022  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 17.023  CALL         Sub Level Signal /437,SWPG
 17.024  ENDW

 17.025  IF           @Error
 17.026  EVAL   -e 0 : An error occurred during the [V @TestName].
 18.001  MATH         @Error = 0
 18.002  END
 18.003  ENDIF

 18.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 18.005  VISA         CALC:MARK:Y?[I]
 18.006  MATH         @10GHz_3 = (MEM - @10GHz_2)
 18.007  HEAD         -2 Insert 10 GHz Splitter Error (Port 3 vs. Port 2)
 18.008  MATH         @Section = "10_GHz"
 18.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @10GHz_3)

 18.010  IF           NOT(Insert)
 18.011  CALL         Sub WIF Error

 18.012  IF           @Error
 18.013  END
 18.014  ENDIF

 18.015  ENDIF

 18.016  HEAD         -2 Power Splitter Tracking (Port 3): 11 GHz
 18.017  MATH         @SWPG_Freq = "11GHz"
 18.018  CALL         Sub Apply /SWPG
 18.019  VISA         FREQ:CENT 11E+9
 18.020  MATH         @CenterFreq = 11E+9
 18.021  437          -2.00D                       11GH              RF N

 18.022  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 18.023  CALL         Sub Level Signal /437,SWPG
 18.024  ENDW

 18.025  IF           @Error
 18.026  EVAL   -e 0 : An error occurred during the [V @TestName].
 19.001  MATH         @Error = 0
 19.002  END
 19.003  ENDIF

 19.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 19.005  VISA         CALC:MARK:Y?[I]
 19.006  MATH         @11GHz_3 = (MEM - @11GHz_2)
 19.007  HEAD         -2 Insert 11 GHz Splitter Error (Port 3 vs. Port 2)
 19.008  MATH         @Section = "11_GHz"
 19.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @11GHz_3)

 19.010  IF           NOT(Insert)
 19.011  CALL         Sub WIF Error

 19.012  IF           @Error
 19.013  END
 19.014  ENDIF

 19.015  ENDIF

 19.016  HEAD         -2 Power Splitter Tracking (Port 3): 12 GHz
 19.017  MATH         @SWPG_Freq = "12GHz"
 19.018  CALL         Sub Apply /SWPG
 19.019  VISA         FREQ:CENT 12E+9
 19.020  MATH         @CenterFreq = 12E+9
 19.021  437          -2.00D                       12GH              RF N

 19.022  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 19.023  CALL         Sub Level Signal /437,SWPG
 19.024  ENDW

 19.025  IF           @Error
 19.026  EVAL   -e 0 : An error occurred during the [V @TestName].
 20.001  MATH         @Error = 0
 20.002  END
 20.003  ENDIF

 20.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 20.005  VISA         CALC:MARK:Y?[I]
 20.006  MATH         @12GHz_3 = (MEM - @12GHz_2)
 20.007  HEAD         -2 Insert 12 GHz Splitter Error (Port 3 vs. Port 2)
 20.008  MATH         @Section = "12_GHz"
 20.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @12GHz_3)

 20.010  IF           NOT(Insert)
 20.011  CALL         Sub WIF Error

 20.012  IF           @Error
 20.013  END
 20.014  ENDIF

 20.015  ENDIF

 20.016  HEAD         -2 Power Splitter Tracking (Port 3): 13 GHz
 20.017  MATH         @SWPG_Freq = "13GHz"
 20.018  CALL         Sub Apply /SWPG
 20.019  VISA         FREQ:CENT 13E+9
 20.020  MATH         @CenterFreq = 13E+9
 20.021  437          -2.00D                       13GH              RF N

 20.022  WHILE        ((MEM < @LoLimit) || (MEM > @HiLimit)) && NOT(@Error)
 20.023  CALL         Sub Level Signal /437,SWPG
 20.024  ENDW

 20.025  IF           @Error
 20.026  EVAL   -e 0 : An error occurred during the [V @TestName].
 21.001  MATH         @Error = 0
 21.002  END
 21.003  ENDIF

 21.004  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)
 21.005  VISA         CALC:MARK:Y?[I]
 21.006  MATH         @13GHz_3 = (MEM - @13GHz_2)
 21.007  HEAD         -2 Insert 13 GHz Splitter Error (Port 3 vs. Port 2)
 21.008  MATH         @Section = "13_GHz"
 21.009  MATH         Insert = WIF(@IniFile, @Section, @Parameter, @13GHz_3)

 21.010  IF           NOT(Insert)
 21.011  CALL         Sub WIF Error

 21.012  IF           @Error
 21.013  END
 21.014  ENDIF

 21.015  ENDIF        ; NOT(Insert)

 21.016  ENDIF        ; NOT(ZCMPI(@ModelNum, "MS2721B"))

 21.017  ELSE

 21.018  M437                        F32           HP8481A        T1
 21.019  ENDIF        ; NOT(EXISTS(@IniFile)) || NOT(Valid)

 21.020  HEAD         -2
 21.021  CALL         Sub Reset /SWPG
 21.022  437          *                                                 S

 21.023  END
