﻿© Fluke Corporation. All Rights Reserved.                   MET/CAL Procedure
=============================================================================
INSTRUMENT:            Sub Anritsu MS272xB Sweep Complete
INSTRUMENT:            Sub Anritsu MS272xB Take Sweep Only
INSTRUMENT:            Sub Anritsu MS272xB Take Sweep (MKF)
INSTRUMENT:            Sub Anritsu MS272xB Take Sweep (MKCF)
INSTRUMENT:            Sub Anritsu MS272xB Take Sweep (MKPK)
INSTRUMENT:            Sub Anritsu MS272xB Take Sweep (MKPK, MKCF)
DATE:                  2007-07-16
AUTHOR:                Fluke
REVISION:              $Revision: 2619 $
ADJUSTMENT THRESHOLD:  70%
NUMBER OF TESTS:       7
NUMBER OF LINES:       193
=============================================================================
#
#  Procedure Author:
#        DFM
#
#  Model(s) Covered:
#        MS2721B, MS2723B, MS2724B
#
#  Compatibility:
#        MET/CAL 7.20 SP3 (7.20X) or later
#
#  Subprocedures:
#        None
#
#  Required Files:
#        None
#
#  Additional Equipment Required:
#        None
#
#  The copyright for this procedure is owned by Fluke Corporation.
#
 STEP    FSC    RANGE NOMINAL        TOLERANCE     MOD1        MOD2  3  4 CON

# Set number of sweeps.
  1.001  MATH         Sweeps = 2

  1.002  JMPL         COMPLETE                     PSUBI("Complete")
  1.003  JMPL         SWEEP                        PSUBI("Only")
  1.004  JMPL         MKF                          PSUBI("(MKF)")
  1.005  JMPL         MKCF                         PSUBI("(MKCF)")
  1.006  JMPL         MKPK                         PSUBI("(MKPK)")
  1.007  JMPL         MKPK_MKCF                    PSUBI("(MKPK, MKCF)")
  1.008  DISP         Called subprocedure not found!
  1.009  END

  1.010  EVAL   Increment Test Number

# ====== Sub Anritsu MS272xB Sweep Complete =================================
#
# This sub queries the status operation bit to determine when the sweep has
# completed.
#
#  Example:
# 1.001  VISA         INIT:IMM[10]
# 1.002  CALL         Sub Anritsu MS272xB Sweep Complete

  2.001  LABEL        COMPLETE

  2.002  DO
  2.003  VISA         STAT:OPER?[10][I]
  2.004  WAIT         [D100]
  2.005  UNTIL        BIT(8, MEM)

  2.006  END

  2.007  EVAL   Increment Test Number

# ====== Sub Anritsu MS272xB Take Sweep Only ================================
#
# This sub takes two sweeps and does not alter the marker, center frequency,
# or any other UUT settings.
#
#  Example:
# 1.001  CALL         Sub Anritsu MS272xB Take Sweep

  3.001  LABEL        SWEEP

  3.002  WHILE        Sweeps > 0
  3.003  VISA         INIT:IMM[10]
  3.004  CALL         Sub Anritsu MS272xB Sweep Complete
# Decrement sweep counter by one.
  3.005  MATH         Sweeps = Sweeps - 1
  3.006  ENDW

  3.007  END

  3.008  EVAL   Increment Test Number

# ====== Sub Anritsu MS272xB Take Sweep (MKF) ===============================
#
# This sub takes two sweeps, placing the active marker at a frequency passed
# by the calling procedure after the second sweep.
#
#  Example:
# 1.001  MATH         @MarkerFreq = 1E+6
# 1.002  CALL         Sub Anritsu MS272xB Take Sweep (MKF)

  4.001  LABEL        MKF

  4.002  WHILE        Sweeps > 0
  4.003  VISA         INIT:IMM[10]
  4.004  CALL         Sub Anritsu MS272xB Sweep Complete
# Decrement sweep counter by one.
  4.005  MATH         Sweeps = Sweeps - 1
  4.006  ENDW

# Set UUT marker to specified frequency in Hertz.
  4.007  VISA         CALC:MARK:X [V @MarkerFreq][10]

  4.008  END

  4.009  EVAL   Increment Test Number

# ====== Sub Anritsu MS272xB Take Sweep (MKCF) ==============================
#
# This sub takes two sweeps, placing the active marker at center frequency
# on the display after each sweep. Note that the active marker may be the
# "delta" marker, if previously specified in the calling procedure.
#
#  Example:
# 1.001  CALL         Sub Anritsu MS272xB Take Sweep (MKCF)

  5.001  LABEL        MKCF

  5.002  WHILE        Sweeps > 0
  5.003  VISA         INIT:IMM[10]
  5.004  CALL         Sub Anritsu MS272xB Sweep Complete
# Set UUT marker to (highest) peak.
  5.005  VISA         CALC:MARK:CENT[10]
# Decrement sweep counter by one.
  5.006  MATH         Sweeps = Sweeps - 1
  5.007  ENDW

  5.008  END

  5.009  EVAL   Increment Test Number

# ====== Sub Anritsu MS272xB Take Sweep (MKPK) ==============================
#
# This sub takes two sweeps, placing the active marker at the highest peak
# present on the display after each sweep. Note that the active marker may
# be the "delta" marker, if previously specified in the calling procedure.
#
#  Example:
# 1.001  CALL         Sub Anritsu MS272xB Take Sweep (MKPK)

  6.001  LABEL        MKPK

  6.002  WHILE        Sweeps > 0
  6.003  VISA         INIT:IMM[10]
  6.004  CALL         Sub Anritsu MS272xB Sweep Complete
# Set UUT marker to (highest) peak.
  6.005  VISA         CALC:MARK:MAX[10]
# Decrement sweep counter by one.
  6.006  MATH         Sweeps = Sweeps - 1
  6.007  ENDW

  6.008  END

  6.009  EVAL   Increment Test Number

# ====== Sub Anritsu MS272xB Take Sweep (MKPK, MKCF) ========================
#
# This sub takes two sweeps, placing the active marker at the highest peak
# present on the display, then moving the marker to the center frequency after
# each sweep. Note that the active marker may be the "delta" marker, if
# specified previously in the calling procedure.
#
#  Example:
# 1.001  CALL         Sub Anritsu MS272xB Take Sweep (MKPK, MKCF)

  7.001  LABEL        MKPK_MKCF

  7.002  WHILE        Sweeps > 0
  7.003  VISA         INIT:IMM[10]
  7.004  CALL         Sub Anritsu MS272xB Sweep Complete
# Set UUT marker to (highest) peak; move marker to center frequency.
  7.005  VISA         CALC:MARK:MAX[10]
  7.006  VISA         CALC:MARK:CENTER[10]
# Decrement sweep counter by one.
  7.007  MATH         Sweeps = Sweeps - 1
  7.008  ENDW

  7.009  END
